==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d1/dcf/currency_8h.js <==
var currency_8h =
[
    [ "CurrencySpec", "d5/d02/structCurrencySpec.html", "d5/d02/structCurrencySpec" ],
    [ "_currency", "d1/dcf/currency_8h.html#a54efbad6773ec0172f8ed7703aee053c", null ],
    [ "_custom_currency", "d1/dcf/currency_8h.html#af035165f06ee6762b2932bfb183cb46c", null ],
    [ "Currencies", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5", [
      [ "CURRENCY_GBP", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a0266869cc94c5e3a56f1d38c37342756", null ],
      [ "CURRENCY_USD", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a7cabc652b065ece754fb276ccaff4288", null ],
      [ "CURRENCY_EUR", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5aabe738093ee7e22dffad31d9f64c880b", null ],
      [ "CURRENCY_JPY", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a602023d363e6ad4edd9f7246ee2a9a85", null ],
      [ "CURRENCY_ATS", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a723e486b80a239357117e8975f0e782f", null ],
      [ "CURRENCY_BEF", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5acd0ba3edbe11a40b68d7f3b78676e724", null ],
      [ "CURRENCY_CHF", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ad7ceed09ee482397314eb114a718346c", null ],
      [ "CURRENCY_CZK", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ad157fb8cefbe79563c3d2528ee0c1693", null ],
      [ "CURRENCY_DEM", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ab45a7fe255f680a2a01e2857901858ed", null ],
      [ "CURRENCY_DKK", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a60429187fb7a158f8198cc70faba5cb7", null ],
      [ "CURRENCY_ESP", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a3496391fa5dc12ba839c8da37de0685b", null ],
      [ "CURRENCY_FIM", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5aaf9bd4b49da8d0a6933e1a908b9518a5", null ],
      [ "CURRENCY_FRF", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a351ddefed8a6f6c17e0f296b146234ff", null ],
      [ "CURRENCY_GRD", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a463e9ca7a9cd16cb143f08be770b39a3", null ],
      [ "CURRENCY_HUF", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5afb3a6f569f379a0fccb3271d0e9ed154", null ],
      [ "CURRENCY_ISK", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5aab3c60412764875ee11f8de1bb6dedc3", null ],
      [ "CURRENCY_ITL", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ad09b5c10f07cc364de62d73429882d19", null ],
      [ "CURRENCY_NLG", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ae9302478cb099ec45459e15aebe2c4da", null ],
      [ "CURRENCY_NOK", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a57b8a0a117f058a668c98487d4b9efb6", null ],
      [ "CURRENCY_PLN", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ad3bfafe121a40cdf4df06f24bda32b93", null ],
      [ "CURRENCY_RON", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5aca9d8b50b849dfe5390199c31d8590ff", null ],
      [ "CURRENCY_RUR", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ad5a38c8599b949ec663614316745e6ec", null ],
      [ "CURRENCY_SIT", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a767dd80305ee51042c796bb959416c51", null ],
      [ "CURRENCY_SEK", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a35fce5f83f59934ea5984caf2849721b", null ],
      [ "CURRENCY_YTL", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a9e392863b28224a6e8e62bf65222d252", null ],
      [ "CURRENCY_SKK", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ad95de3984686a6865f930672edf94072", null ],
      [ "CURRENCY_BRL", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a1bbee0775bed167a4f65deae0b66060b", null ],
      [ "CURRENCY_EEK", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a9adc4fa75f887ac27c6692e7e0bb0900", null ],
      [ "CURRENCY_LTL", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5adfa30034005048207a90c974b4da3c4c", null ],
      [ "CURRENCY_KRW", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5af70822c2b88769251f267f3c76739aed", null ],
      [ "CURRENCY_ZAR", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ac07578f24ab8ffc3714922cf6d45c560", null ],
      [ "CURRENCY_CUSTOM", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ae1954b9ac053c721e3749778a4937da7", null ],
      [ "CURRENCY_GEL", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a6b075c315560b1d50b14f7b7a32648d0", null ],
      [ "CURRENCY_IRR", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5aff489b4b7759d91626de1fe354161ad7", null ],
      [ "CURRENCY_RUB", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a47f945d727682b8d265a1d35783879dd", null ],
      [ "CURRENCY_MXN", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5aa115f105a2582cac4a4a0a3577db1c1d", null ],
      [ "CURRENCY_END", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a9182d67662a33b0eb17beee97ec6d611", null ]
    ] ],
    [ "BuildCurrencyDropdown", "d1/dcf/currency_8h.html#af25fea54f14b57a5e3ff30753786486b", null ],
    [ "CheckSwitchToEuro", "d1/dcf/currency_8h.html#ab016d355f7c7466d2824aa8064cf6cc0", null ],
    [ "GetMaskOfAllowedCurrencies", "d1/dcf/currency_8h.html#a84d2ced8e8863a9d9545a34d1d0bcbf0", null ],
    [ "GetNewgrfCurrencyIdConverted", "d1/dcf/currency_8h.html#a019b9fe777966775d47ad4ee0b774d11", null ],
    [ "ResetCurrencies", "d1/dcf/currency_8h.html#aea79705c9482d70818d3672d95a8e143", null ],
    [ "_currency_specs", "d1/dcf/currency_8h.html#a6ec7f30567883f06f908ae21c6c5c42f", null ],
    [ "CF_ISEURO", "d1/dcf/currency_8h.html#ad0b9e1c176db91b31b9af633ace0767b", null ],
    [ "CF_NOEURO", "d1/dcf/currency_8h.html#a8bcdce93d884d0162f66ac44ed119555", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d1/dcf/currency_8h.js <==
var currency_8h =
[
    [ "CurrencySpec", "d5/d02/structCurrencySpec.html", "d5/d02/structCurrencySpec" ],
    [ "_currency", "d1/dcf/currency_8h.html#a54efbad6773ec0172f8ed7703aee053c", null ],
    [ "_custom_currency", "d1/dcf/currency_8h.html#af035165f06ee6762b2932bfb183cb46c", null ],
    [ "Currencies", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5", [
      [ "CURRENCY_GBP", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a0266869cc94c5e3a56f1d38c37342756", null ],
      [ "CURRENCY_USD", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a7cabc652b065ece754fb276ccaff4288", null ],
      [ "CURRENCY_EUR", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5aabe738093ee7e22dffad31d9f64c880b", null ],
      [ "CURRENCY_JPY", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a602023d363e6ad4edd9f7246ee2a9a85", null ],
      [ "CURRENCY_ATS", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a723e486b80a239357117e8975f0e782f", null ],
      [ "CURRENCY_BEF", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5acd0ba3edbe11a40b68d7f3b78676e724", null ],
      [ "CURRENCY_CHF", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ad7ceed09ee482397314eb114a718346c", null ],
      [ "CURRENCY_CZK", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ad157fb8cefbe79563c3d2528ee0c1693", null ],
      [ "CURRENCY_DEM", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ab45a7fe255f680a2a01e2857901858ed", null ],
      [ "CURRENCY_DKK", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a60429187fb7a158f8198cc70faba5cb7", null ],
      [ "CURRENCY_ESP", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a3496391fa5dc12ba839c8da37de0685b", null ],
      [ "CURRENCY_FIM", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5aaf9bd4b49da8d0a6933e1a908b9518a5", null ],
      [ "CURRENCY_FRF", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a351ddefed8a6f6c17e0f296b146234ff", null ],
      [ "CURRENCY_GRD", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a463e9ca7a9cd16cb143f08be770b39a3", null ],
      [ "CURRENCY_HUF", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5afb3a6f569f379a0fccb3271d0e9ed154", null ],
      [ "CURRENCY_ISK", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5aab3c60412764875ee11f8de1bb6dedc3", null ],
      [ "CURRENCY_ITL", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ad09b5c10f07cc364de62d73429882d19", null ],
      [ "CURRENCY_NLG", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ae9302478cb099ec45459e15aebe2c4da", null ],
      [ "CURRENCY_NOK", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a57b8a0a117f058a668c98487d4b9efb6", null ],
      [ "CURRENCY_PLN", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ad3bfafe121a40cdf4df06f24bda32b93", null ],
      [ "CURRENCY_RON", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5aca9d8b50b849dfe5390199c31d8590ff", null ],
      [ "CURRENCY_RUR", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ad5a38c8599b949ec663614316745e6ec", null ],
      [ "CURRENCY_SIT", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a767dd80305ee51042c796bb959416c51", null ],
      [ "CURRENCY_SEK", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a35fce5f83f59934ea5984caf2849721b", null ],
      [ "CURRENCY_YTL", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a9e392863b28224a6e8e62bf65222d252", null ],
      [ "CURRENCY_SKK", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ad95de3984686a6865f930672edf94072", null ],
      [ "CURRENCY_BRL", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a1bbee0775bed167a4f65deae0b66060b", null ],
      [ "CURRENCY_EEK", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a9adc4fa75f887ac27c6692e7e0bb0900", null ],
      [ "CURRENCY_LTL", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5adfa30034005048207a90c974b4da3c4c", null ],
      [ "CURRENCY_KRW", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5af70822c2b88769251f267f3c76739aed", null ],
      [ "CURRENCY_ZAR", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ac07578f24ab8ffc3714922cf6d45c560", null ],
      [ "CURRENCY_CUSTOM", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5ae1954b9ac053c721e3749778a4937da7", null ],
      [ "CURRENCY_GEL", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a6b075c315560b1d50b14f7b7a32648d0", null ],
      [ "CURRENCY_IRR", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5aff489b4b7759d91626de1fe354161ad7", null ],
      [ "CURRENCY_RUB", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a47f945d727682b8d265a1d35783879dd", null ],
      [ "CURRENCY_MXN", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5aa115f105a2582cac4a4a0a3577db1c1d", null ],
      [ "CURRENCY_NTD", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a94c19108e046dc3ba6b966707b0ea0e7", null ],
      [ "CURRENCY_CNY", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a1e844251432264cf1c49b0f231459fbc", null ],
      [ "CURRENCY_HKD", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5aed2ae827e8bd51a466759e6bc09dcd4e", null ],
      [ "CURRENCY_INR", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a5818fb37b753132060057e9ef86d1dc7", null ],
      [ "CURRENCY_END", "d1/dcf/currency_8h.html#ae3d856d665e273120a7178a0349d37a5a9182d67662a33b0eb17beee97ec6d611", null ]
    ] ],
    [ "BuildCurrencyDropdown", "d1/dcf/currency_8h.html#af25fea54f14b57a5e3ff30753786486b", null ],
    [ "CheckSwitchToEuro", "d1/dcf/currency_8h.html#ab016d355f7c7466d2824aa8064cf6cc0", null ],
    [ "GetMaskOfAllowedCurrencies", "d1/dcf/currency_8h.html#a84d2ced8e8863a9d9545a34d1d0bcbf0", null ],
    [ "GetNewgrfCurrencyIdConverted", "d1/dcf/currency_8h.html#a019b9fe777966775d47ad4ee0b774d11", null ],
    [ "ResetCurrencies", "d1/dcf/currency_8h.html#aea79705c9482d70818d3672d95a8e143", null ],
    [ "_currency_specs", "d1/dcf/currency_8h.html#a6ec7f30567883f06f908ae21c6c5c42f", null ],
    [ "CF_ISEURO", "d1/dcf/currency_8h.html#ad0b9e1c176db91b31b9af633ace0767b", null ],
    [ "CF_NOEURO", "d1/dcf/currency_8h.html#a8bcdce93d884d0162f66ac44ed119555", null ]
];
